AdaptiveAccuracyEngine class

Dynamic Adaptive Accuracy Engine.

Automatically adjusts requested GPS location accuracy based on user velocity, activity type, indoor/outdoor environment, and device battery level.

Constructors

AdaptiveAccuracyEngine()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

computeAccuracy({required ActivityType activity, double speedMps = 0.0, double batteryLevelPercent = 100.0, IndoorOutdoorState envState = IndoorOutdoorState.unknown}) LocationAccuracy
Calculate recommended LocationAccuracy level.