BatteryUsageReport class

Diagnostic Battery Usage Report model.

Constructors

BatteryUsageReport({required Duration activeRuntime, required int totalFixes, required BatteryProfile appliedProfile, required double batteryUsedPercent, required double estimatedDrainRatePerHour, required String efficiencyRating})
const

Properties

activeRuntime Duration
final
appliedProfile BatteryProfile
final
batteryUsedPercent double
final
efficiencyRating String
final
estimatedDrainRatePerHour double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalFixes int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited