CoordinateTools class

Geodesy and Coordinate Conversion utilities.

Constructors

CoordinateTools()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWebMercator(WebMercatorCoordinate mercator) LatLng
Converts Web Mercator (EPSG:3857) to LatLng (WGS84).
toDms(LatLng point) String
Converts decimal degrees LatLng to DMS (Degrees, Minutes, Seconds) formatted string.
toUtm(LatLng point) UtmCoordinate
Approximate conversion from LatLng to UTM coordinate.
toWebMercator(LatLng point) WebMercatorCoordinate
Converts LatLng (WGS84) to Web Mercator (EPSG:3857).