FusedSensorState class

Fused Sensor State output.

Constructors

FusedSensorState({required double tiltCompensatedHeadingDeg, required int estimatedStepsCount, required double estimatedFloorLevel, required bool isMovingByVibration})
const

Properties

estimatedFloorLevel double
final
estimatedStepsCount int
final
hashCode int
The hash code for this object.
no setterinherited
isMovingByVibration bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tiltCompensatedHeadingDeg double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited