LocationReplayStream class

Controller for replaying historical location routes.

Constructors

LocationReplayStream({required List<AllInOneLocation> route, double speedMultiplier = 1.0, Duration sampleInterval = const Duration(seconds: 1)})

Properties

hashCode int
The hash code for this object.
no setterinherited
isReplaying bool
no setter
route List<AllInOneLocation>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleInterval Duration
final
speedMultiplier double
final
stream Stream<AllInOneLocation>
no setter

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Pauses route replay.
start() → void
Starts or resumes route replay stream.
stop() → void
Stops route replay and resets index to 0.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited