OfflineGeofenceCache class

Offline storage manager for persistent geofence regions.

Constructors

OfflineGeofenceCache()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearGeofences() Future<bool>
Clear offline geofences cache.
loadGeofences() Future<List<GeofenceRegion>>
Load persisted geofence regions from SharedPreferences storage.
saveGeofences(List<GeofenceRegion> regions) Future<bool>
Save geofence regions to local SharedPreferences storage.