RouteCompressor class

Ramer-Douglas-Peucker (RDP) Route Compressor.

Simplifies 2D GPS trajectory paths by discarding intermediate points within a specified perpendicular distance tolerance epsilon.

Constructors

RouteCompressor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compress(List<AllInOneLocation> points, {double epsilonMeters = 5.0}) CompressionResult
Compress a list of AllInOneLocation points using Ramer-Douglas-Peucker.