RouteProgress class

Route Progress summary record.

Constructors

RouteProgress({required double totalRouteDistanceMeters, required double distanceTraveledMeters, required double distanceRemainingMeters, required double completionPercentage, required bool isOffRoute, required EtaEstimate eta, RouteSnapResult? snapResult})
const

Properties

completionPercentage double
final
distanceRemainingMeters double
final
distanceTraveledMeters double
final
eta EtaEstimate
final
hashCode int
The hash code for this object.
no setterinherited
isOffRoute bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapResult RouteSnapResult?
final
totalRouteDistanceMeters double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited