allinone library

Classes

AdaptiveAccuracyEngine
Dynamic Adaptive Accuracy Engine.
AdaptiveBatteryEngine
Adaptive Battery Engine.
AdaptiveTrackingParameters
Dynamic background parameters recommended by adaptive battery engine.
AllInOneBackground
Background location tracker that works even when the screen is off.
AllInOneConfig
Master configuration for the AllInOne package.
AllInOneDiagnosticDashboard
Interactive Developer Diagnostic Dashboard Widget.
AllInOneKalmanFilter
2D Kalman Filter for location smoothing.
AllInOneLocation
Unified location model that wraps geolocator Position. Provides a clean API regardless of whether the location came from foreground or background.
AllInOneLocationService
High-accuracy enterprise location engine.
AllInOnePermission
Unified permission manager for all app permissions.
BackgroundConfig
Configuration for background location tracking service.
BackgroundRecoveryService
Background Recovery Service & Watchdog Manager.
CompressionResult
Result of route compression.
FlutterBackgroundService
GeofenceEvent
Geofence event record.
GeofenceRegion
Geofence region definition.
IndoorOutdoorEngine
Indoor / Outdoor environment detection engine.
LatLng
Point structure for coordinates.
LocationAnalytics
Enterprise tracking session analytics metrics summary.
LocationAnalyticsEngine
Enterprise Location Analytics Engine.
MockLocationDetector
Multi-heuristic Mock Location Detector.
MockLocationResult
Inspection result from MockLocationDetector.
MotionDetector
Motion detection & Activity recognition engine.
OfflineLocationQueue
Persistent offline location queue.
OfflineLocationSync
Offline Location Sync Manager.
Permission
Defines the permissions which can be checked and requested.
Position
Contains detailed location information.
ProviderSelector
Automatic Provider Selector & Retry Handler.
RouteCompressor
Ramer-Douglas-Peucker (RDP) Route Compressor.
ServiceInstance
SmartGeofenceManager
Smart Geofence Manager.
SyncStats
Sync attempt result statistics.

Enums

ActivityType
Activity recognition type enum.
BatteryProfile
Battery optimization profile for adaptive tracking.
GeofenceEventType
Geofence event trigger type.
GeofenceShape
Geofence region shape type.
IndoorOutdoorState
Indoor / Outdoor environment state enum.
LocationAccuracy
Represent the possible location accuracy values.
LocationPermission
Represent the possible location permissions.
LocationProviderStrategy
Provider selector strategy.
PermissionStatus
Defines the state of a Permission.

Extensions

PermissionStatusGetters on PermissionStatus
Utility getter extensions for the PermissionStatus type.

Typedefs

OnHeartbeat = Future<void> Function()
Callback type for heartbeat events in the background.
OnLocationUpdate = Future<void> Function(AllInOneLocation location)
Callback type for location updates in the background.
OnShowNotification = void Function(String? userId, String content)
Callback type for notification display in the background.