BeaconData class
Standardized BLE Beacon model.
Constructors
Properties
- beaconLocation → LatLng?
-
final
- estimatedDistance → double
-
Calculates estimated distance in meters using Log-Distance Path Loss model.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- instanceId → String?
-
final
- major → int?
-
final
- minor → int?
-
final
- namespace → String?
-
final
- proximity → BeaconProximity
-
Estimates proximity status based on distance.
no setter
- rssi → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- txPower → int
-
final
- type → BeaconType
-
final
- url → String?
-
final
- uuid → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited