BoundingBox class
Bounding Box spatial structure.
Constructors
- BoundingBox({required double minLatitude, required double maxLatitude, required double minLongitude, required double maxLongitude})
-
const
-
BoundingBox.fromPoints(List<
LatLng> points) -
factory
Properties
- center → LatLng
-
no setter
- estimatedZoomLevel → int
-
Calculates estimated map zoom level for fitting this bounding box into screen width.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLatitude → double
-
final
- maxLongitude → double
-
final
- minLatitude → double
-
final
- minLongitude → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
contains(
LatLng point) → bool -
expand(
double marginMeters) → BoundingBox -
intersects(
BoundingBox other) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toGeoJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited