GeocodingCacheEntry class
Cache entry for reverse geocoding lookup.
Constructors
- GeocodingCacheEntry({required String address, required double latitude, required double longitude, required DateTime timestamp})
-
const
-
GeocodingCacheEntry.fromMap(Map<
String, dynamic> map) -
factory
Properties
Methods
-
isExpired(
Duration ttl) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited