ProviderSelector class
Automatic Provider Selector & Retry Handler.
Implements exponential backoff retries and fallback strategy switching
using Google Fused Location Provider (forceLocationManager: false).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
executeWithRetry<
T> ({required Future< T> action(int attempt), int maxAttempts = defaultMaxAttempts, Duration initialDelay = defaultInitialDelay, double backoffMultiplier = 2.0}) → Future<T> - Execute an asynchronous location operation with exponential backoff retries.
-
getLocationWithFallback(
{Duration timeout = const Duration(seconds: 10)}) → Future< AllInOneLocation?> - Get location using provider fallback strategy with Google Fused Location.
Constants
- defaultInitialDelay → const Duration
- defaultMaxAttempts → const int